import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;
import com.sun.javafx.binding.StringFormatter;

import java.util.Scanner;

public class AccountApp {

    Scanner scanner = new Scanner(System.in);
    // we are using a MySQl database
    private final static String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";

    private Dao<Account, Integer> accountDao;

    public static void main(String[] args) throws Exception {
        // turn our static method into an instance of Main
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        ConnectionSource connectionSource = null;
        try {
            // create our data-source for the database
            connectionSource = new JdbcConnectionSource(DATABASE_URL, "root", "Zipcode4.2");
            // setup our  DAOs
            setupDao(connectionSource);
            // read, write and delete some data
            processData();

        } finally {
            // destroy the data source which should close underlying connectionsgit
            if (connectionSource != null) {
                connectionSource.close();
            }
        }
    }

    /**
     * Read and write some example data.
     */
    private void processData() throws Exception {
        try {
            boolean crud = true;
            while (crud) {
                System.out.println("What would you like to do?  Please select a number from below:\n1.Create\n2.Read\n3.Update\n4.Delete\n5.Quit");
                int choice = scanner.nextInt();

                switch (choice) {
                    case 1:
                        createMethod();
                        break;
                    case 2:
                        readMethod();
                        break;
                    case 3:
                        updateMethod();
                        break;
                    case 4:
                        deleteMethod();
                        break;
                    case 5:
                        crud = false;
                        System.out.println("Thanks for using our database!  Have a fantastic day!");
                        break;
                }

            }
        } catch (Exception e) {
            System.out.println("Error");

        }
    }

    private void readMethod() {
        try {
            System.out.println("What is the id for the row you would you like to read?  Type 0 to read all.");
            int row = scanner.nextInt();
            if(row == 0) {
                String result = String.format("| %6s | %20s | %20s |", "id", "name", "password") + "\n";
                for(Account account : accountDao.queryForAll()) {
                    result += String.format("| %6d | %20s | %20s |", account.getId(), account.getName(), account.getPassword()) + "\n";
                }
                System.out.println(result);
            } else {
                Account thisAccount = accountDao.queryForId(row);
                System.out.println(String.format("| %6s | %20s | %20s |", "id", "name", "password"));
                System.out.println(String.format("| %6d | %20s | %20s |", thisAccount.getId(), thisAccount.getName(), thisAccount.getPassword()));
            }
        } catch (Exception e) {
            System.out.println("Error");
        }
    }

    private void deleteMethod() {
        try {
            System.out.println("Please enter the id of the account you would like to delete");
            int id = scanner.nextInt();
            accountDao.deleteById(id);
        } catch (Exception e) {
            System.out.println("Error");
        }
    }

    private void updateMethod() {
        try {
            System.out.println("What is the id of the user you would you like to update?");
            int row = scanner.nextInt();
            Account account = accountDao.queryForId(row);
            System.out.println("What would you like to update?\n1.Name\n2.Password");
            int choice3 = scanner.nextInt();
            if (choice3 == 1) {
                System.out.println("Enter new name");
                Scanner scanner2 = new Scanner(System.in);
                String newName = scanner2.nextLine();
                account.setName(newName);
                accountDao.update(account);
            } else {
                System.out.println("Enter new password");
                Scanner scanner3 = new Scanner(System.in);
                String newPassword = scanner3.nextLine();
                account.setName(newPassword);
                accountDao.update(account);
            }
        } catch (Exception e) {
            System.out.println("Error");
        }
    }

    private void createMethod() {

        try {
            System.out.print("Please enter the name on the account: ");
            Scanner scanner4 = new Scanner(System.in);
            String name = scanner4.nextLine();
            Account account = new Account(name);
            accountDao.create(account);
            int id = account.getId();
            System.out.println("User id is: " + id);
            System.out.print("Please enter a password for the account: ");
            Scanner scanner5 = new Scanner(System.in);
            String password = scanner5.nextLine();
            account.setPassword(password);
            accountDao.update(account);
        } catch (Exception e) {
            System.out.println("Error");
        }


    }

    /**
     * Setup our  DAOs
     */
    private void setupDao(ConnectionSource connectionSource) throws Exception {

        accountDao = DaoManager.createDao(connectionSource, Account.class);

    }
}